@@ -36,7 +36,6 @@ action_list = ActionList.as_view()
 class ActionsForPeriod(ActionList):
     previous = None
     template_name = "activity_monitor/grouped.html"
-    showing_current_day = False
     next = None
     previous = None
 
@@ -76,11 +75,8 @@ class ActionsForPeriod(ActionList):
         context['actions'] = group_activities(self.get_queryset())
         if self.day:
             context['current_date_string'] = self.current_day.strftime('%B %d %Y')
-            if self.current_day == datetime.date.today():
-                self.showing_current_day = True
         else:
             context['current_date_string'] = datetime.date(self.year, self.month, 1).strftime('%B %Y')
-        context['showing_current_day'] = self.showing_current_day
         return context
 actions_for_period = ActionsForPeriod.as_view()
 
